'use client';
import { pageData } from "@/utils/Data";
import axios from "axios";
import React, { useEffect } from "react";
import { createContext,useState } from "react";
type ContextType= {
    theme: 'dark' | 'light'
    ToggleTheme: () => void;
    data:{
    id: number;
    blogTitle: string;
    authorDetails: {
        author: string;
        date: Date;
        authorImg: string;
    };
    category: string;
    readingTime: number;
    content: string;
    categories: string[];
    banner: {
        img: string;
        width: number;
        height: number;
    };
    description: string;
}[],
    handleFilter: (search: string) => void
    start: number;
    end: number;
    size: number;
    currentPage: number;
    handleChangePage: (page: number) => void;
    }
export const Context = createContext<ContextType>({
    start: 1,
    end: 1,
    size: 1,
    currentPage: 1,
    handleChangePage: () => { },
    data: pageData,
    handleFilter: () => { },
    theme: 'dark',
    ToggleTheme:()=>{}
})
interface AppContextProps{
    children: React.ReactNode
}
const AppContext = ({ children }: AppContextProps) => {
    const [theme, setTheme] = useState<'light' | 'dark'>('dark');
    const ToggleTheme = () => {
        if (theme === 'light') setTheme('dark');
        else if (theme === 'dark') setTheme('light');
    }
    const [currentPage, setcurrentPage] = useState(1);
    const size = 6;
    const [start, setstart] = useState(0);
    const [end, setend] = useState(size);
    const handleChangePage = (page: number) => {
        setcurrentPage(page);
        setstart((page - 1) * size);
        setend(page * size);
    }
        const [filter, setFilter] = useState<any>([]);
    const [pageData, setPageData] = useState<any>([]);

    // Fetch data from API and set state
    useEffect(() => {
        const fetchData = async () => {
            try {
                const res = await axios.get('http://localhost:3000/api/');
                setPageData(res.data.Data);
                setFilter(res.data.Data); // Set filter with fetched data
            } catch (error) {
                console.error("Error fetching data:", error);
            }
        };

        fetchData();
    }, []);

    // Handle filtering of data based on search input
    const handleFilter = (search:string) => {
        if (search.trim() === "") {
            setFilter(pageData);
        } else {
            setFilter(
                pageData.filter((data:any) =>
                    data.blogTitle.toLowerCase().includes(search.toLowerCase())
                )
            );
        }
    };
    return (<Context.Provider value={{
        theme,
        ToggleTheme,
        data: filter,
        handleFilter,
        start,
        end,
        size,
        currentPage,
        handleChangePage,
    }}>
        {children}
    </Context.Provider> );
}
 
export default AppContext;